@@ -772,16 +772,16 @@ void SqueezsterCore::mapParse(const QVariantMap& map, const QByteArray& command,
             playerCount=serverStatus()[S_P_COUNT].toString().toInt();
             _DEBUG_ << "mapParse(): Player count:" << playerCount;
             setOtherPlayersList(serverStatus()[S_O_P_LOOP].toList());
-            setPlayersList(serverStatus()[S_P_LOOP].toList());
-
+            playersList_i = serverStatus()[S_P_LOOP].toList(); // Do not send a signal yet
             for(int i=0;i<playerCount;i++) {
                 playerID_i=playersList().at(i).toMap()[S_P_ID].toString().toUtf8();
 
                 if(isValidPlayer(playerID_i)) { // Avoid SQUEEZENETWORK player FF:FF:FF:FF:FF
                     playersMap[playerID_i]=playersList().at(i).toMap();
-                    _DEBUG_ << "mapParse(): Player ID:" << playerID_i;
+                    _DEBUG_ << "mapParse(): Player ID:" << playerID_i << "index:" << i;
                     if(activePlayer()==playerID_i) {
-                        setActivePlayerIndex(i);
+                        setPlayersList(serverStatus()[S_P_LOOP].toList(),i);
+                        //setActivePlayerIndex(i);
                         activePlayerFound=true;
                     }
                     if(!onMysb())
@@ -791,7 +791,8 @@ void SqueezsterCore::mapParse(const QVariantMap& map, const QByteArray& command,
             // If the saved player isn't available, choose the last from the list
             if(!activePlayerFound){
                 setActivePlayer(playerID_i);
-                setActivePlayerIndex(playerCount-1);
+                setPlayersList(serverStatus()[S_P_LOOP].toList(),0);
+                //setActivePlayerIndex(playerCount-1);
             }
             _DEBUG_ << "Active player index:" << activePlayerIndex();
             playerStatusSlot();
@@ -1168,13 +1169,13 @@ void SqueezsterCore::writeOptionsSettings()
 //----------------------------------------------------------
 void SqueezsterCore::readSettings() // UserSettings &newSettings)
 {
-    _DEBUG_ << "SqueezsterCore::readSettings(UserSettings &newSettings)";
+    qDebug() << "SqueezsterCore::readSettings(UserSettings &newSettings)";
 
     QVariantMap connectionSettings;
     QVariantMap optionsSettings;
 
-    QByteArray newActivePlayer=squeezsterSettings->value("lastusedplayer","").toString().toUtf8();
-    _DEBUG_ << "readSettings() Setting player: " << squeezsterSettings->value("lastusedplayer","").toString().toUtf8();
+    QByteArray newActivePlayer=squeezsterSettings->value("lastusedplayer","").toByteArray();
+    qDebug() << "readSettings() Setting player: " << squeezsterSettings->value("lastusedplayer","").toByteArray();
     optionsSettings["screensaverinhibited"]=squeezsterSettings->value("screensaverinhibited",false).toBool();
     optionsSettings["albumicons"]=squeezsterSettings->value("albumicons",false).toBool();
     optionsSettings["largealbumicons"]=squeezsterSettings->value("largealbumicons",false).toBool();
