@@ -117,6 +117,12 @@ public:
         }
     }
 
+    void setActivePlayer(QVariantMap playerMap) {
+        _DEBUG_ << "setActivePlayer(QVariantMap playerMap)" << playerMap.value("playerid").toByteArray();
+        QByteArray playerID = playerMap.value("playerid").toByteArray();
+        setActivePlayer(playerID);
+    }
+
     Q_PROPERTY(int activePlayerIndex READ activePlayerIndex WRITE setActivePlayerIndex NOTIFY activePlayerIndexChanged)
     Q_INVOKABLE int activePlayerIndex() const {return activePlayerIndex_i;}
     Q_INVOKABLE void setActivePlayerIndex(int activePlayerIndex) {activePlayerIndex_i=activePlayerIndex;emit activePlayerIndexChanged();}
@@ -165,6 +171,7 @@ public:
     Q_INVOKABLE void setPlayersList(const QVariantList& playersList) {playersList_i = playersList;  _DEBUG_ << "setPlayerslist";emit playersListChanged();}
     Q_INVOKABLE QVariantList playersList() const {return(playersList_i);}
     Q_INVOKABLE QVariantMap getPlayersList(int i) const {if(playersList_i.count())return(playersList_i[i].toMap());else return(QVariantMap());}
+    void setPlayersList(const QVariantList& playersList, quint16 i) {playersList_i = playersList; activePlayerIndex_i=i; _DEBUG_ << "setPlayerslist";emit playersListChanged();}
 
     Q_PROPERTY(QVariantList otherPlayersList READ otherPlayersList WRITE setOtherPlayersList NOTIFY otherPlayersListChanged)
     Q_INVOKABLE void setOtherPlayersList(const QVariantList& otherPlayersList) {otherPlayersList_i = otherPlayersList;  _DEBUG_ << "setotherPlayersList";emit otherPlayersListChanged();}
@@ -272,6 +279,27 @@ public:
         }
         return "";
     }
+
+    QByteArray activePlayerID(quint16 index)
+    {
+     _DEBUG_ <<  "activePlayerID(quint16 index)" << index;
+        if(index >= 0 && index < playersList().count()) {
+            _DEBUG_ << "Player:" << playlistsList().at(index).toMap().value("playerid").toByteArray();
+            return playlistsList().at(index).toMap().value("playerid").toByteArray();
+        } else {
+            return "";
+        }
+    }
+
+    int activePlayerIndex()
+    {
+        for(int i=0;i<playersList().count();i++) {
+            if(activePlayer()==playersList().at(i).toMap().value("playerid")) {
+                return(i);
+            }
+        }
+        return -1;
+    }
     QPointer<QNetworkAccessManager> networkManager() {return httpNetworkManager;}
 
 signals:
