@@ -2,6 +2,11 @@
 #define CONSTANTS_H
 
 // Constants;
+// Debug configuration:
+#ifndef DEBUG_MODE
+  #define DEBUG_MODE 0 // 1 Debug enabled, 0 Debug disabled
+#endif
+
 #define NORMALSCREENOFFSET 46
 #define PROGRESSINTERVAL 2000
 #define ITEMSELECTTIME 500
