@@ -55,7 +55,6 @@ squeezster::squeezster(int debug,QWidget *parent) :
     connect(&core,SIGNAL(playersListChanged()),this,SLOT(playersListChangedSlot()));
     connect(&core,SIGNAL(serverListChanged()),this,SLOT(serverListChangedSlot()));
     connect(&core,SIGNAL(playerStatusChanged()),this,SLOT(updateStatus()));
-    //connect(&core,SIGNAL(serverStatusChanged()),this,SLOT(playersListChangedSlot()));
     connect(&core,SIGNAL(activePlayerIndexChanged()),this,SLOT(activePlayerIndexChangedSlot()));
     connect(&core,SIGNAL(albumartUrlChanged()),this,SLOT(updateAlbumArtLabel()));
 
@@ -906,7 +905,7 @@ void squeezster::slotOptions()
 //----------------------------------------------
 // squeezster::setAlbumsListView()
 //----------------------------------------------
-void squeezster::setAlbumsListView()
+void squeezster::setAlbumsListView(bool loadList)
 {
     _DEBUG_ << "squeezster::setAlbumsListView()";
     if (core.optionsSettings().value("albumicons").toBool()) { // iconview
@@ -929,8 +928,10 @@ void squeezster::setAlbumsListView()
         ui->albumsListWidget->setIconSize(QSize(50,50));
         ui->albumsListWidget->setViewMode(QListView::ListMode);
     }
-    ui->albumsListWidget->clear();
-    initAlbumsList();
+    if (ui->stackedWidget->currentIndex()==0 && ui->squeezeTabWidget->currentIndex()==2) {
+        ui->albumsListWidget->clear();
+        initAlbumsList();
+    }
 }
 
 //----------------------------------------------
@@ -1159,6 +1160,7 @@ void squeezster::initUI()
     connect(ui->actionMusicLibraryView, SIGNAL(triggered()),this,SLOT(slotMusicLibraryView()));
     connect(ui->actionRescanMusicLibrary,SIGNAL(triggered()),this,SLOT(slotRescan()));
     connect(ui->squeezeTabWidget, SIGNAL(currentChanged(int)),this,SLOT(slotTabWidgetCurrentChanged(int)));
+    connect(ui->playerComboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(playerChangedSlot()));
 
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(setupScreenMode()));
 
@@ -1317,13 +1319,24 @@ void squeezster::appsListChangedSlot()
 }
 void squeezster::playersListChangedSlot()
 {
-    _DEBUG_ << "playersListChangedSlot";
+    _DEBUG_ << "playersListChangedSlot activePlayer():" << core.activePlayer() << core.activePlayerIndex();
+    disconnect(ui->playerComboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(playerChangedSlot()));
     ui->playerComboBox->clear();
-    for(int i=0;i<core.playersList().count();i++)
+    for(int i=0;i<core.playersList().count();i++) {
+        _DEBUG_ << "playersListChangedSlot" << i;
         ui->playerComboBox->addItem(core.playersList().at(i).toMap().value("name").toString(),core.playersList().at(i).toMap());
+    }
+    _DEBUG_ << "playersListChangedSlot -> set current index" << core.activePlayerIndex();
+    ui->playerComboBox->setCurrentIndex(core.activePlayerIndex());
+    connect(ui->playerComboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(playerChangedSlot()));
 }
+void squeezster::playerChangedSlot() {
+    _DEBUG_ << "playerChangedSlot()" << ui->playerComboBox->currentIndex() << ui->playerComboBox->itemData(ui->playerComboBox->currentIndex()).toMap().value("playerid").toByteArray();
+    core.setActivePlayer(ui->playerComboBox->itemData(ui->playerComboBox->currentIndex()).toMap());
+}
+
 void squeezster::activePlayerIndexChangedSlot() {
-    _DEBUG_ << "activePlayerIndexChangedSlot()";
+    _DEBUG_ << "activePlayerIndexChangedSlot() index" << core.activePlayerIndex();
     ui->playerComboBox->setCurrentIndex(core.activePlayerIndex());
 }
 
