@@ -1,6 +1,7 @@
 #ifndef SQUEEZSTER_H
 #define SQUEEZSTER_H
 
+#include "constants.h"
 #include <QMainWindow>
 #include <QtNetwork>
 #include <QMetaType>
@@ -35,7 +36,6 @@
 #include "listwidgetitemnetworkrequest.h"
 #include "treewidgetitemnetworkrequest.h"
 #include "metatypes.h"
-#include "constants.h"
 
 QTM_USE_NAMESPACE
 
@@ -117,6 +117,7 @@ private slots:
     void appsListChangedSlot();
     void playersListChangedSlot();
     void serverListChangedSlot();
+    void playerChangedSlot();
     void activePlayerIndexChangedSlot();
     void listListChangedSlot();
     void treeListChangedSlot();
@@ -144,7 +145,7 @@ private slots:
     void showPlaylists();
 
     void showMusicLibraryView();
-    void setAlbumsListView();
+    void setAlbumsListView(bool loadList=true);
     void treeContextMenuHandler(QPoint point);
     void listContextMenuHandler(QPoint point);
 
